#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import print_function
import os
import argparse
from SimpleCV import Image, HaarCascade

# HaarCascade to segment faces
segment_face = HaarCascade(os.path.join(os.path.dirname(__file__), "haarcascade_frontalface_alt.xml"))


def get_faces(image_path, api_mode=False):
    """
    Return a list of cropped faces given an image path

    :param image_path: Path to image
    :type image_path: str
    :param api_mode: If api_mode is True get_faces returns a list of found HaarFeatures
    :type api_mode: bool
    :returns: list of images
    """

    original_image = Image(image_path)
    faces = original_image.findHaarFeatures(segment_face)

    if api_mode:
        return faces
    else:
        return [face.crop() for face in faces]


def main():
    """
    Execution as command
    """

    parser = argparse.ArgumentParser(description='Extracts faces from an image')
    parser.add_argument('-i', '--image-path', help='Image path', required=True)
    parser.add_argument('-o', '--output-dir', help='Output directory', required=True)
    parser.add_argument('-v', '--verbose', help='Verbose', required=False, action='store_true')
    options = vars(parser.parse_args())

    faces = get_faces(options['image_path'])

    if options['verbose']:
        print("Found {} faces on {}".format(len(faces), options['image_path']))
    for n, face in enumerate(faces):
        face.save(os.path.join(options['output_dir'], 'face_{}.jpg'.format(n)))

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')
version = __import__('facehugger').__version__

setup(
    name='facehugger',
    version=version,
    description='Extracts faces from an image',
    long_description=readme + '\n\n' + history,
    author='Diego Navarro Mellen',
    author_email='dnmellen@gmail.com',
    url='https://github.com/dnmellen/facehugger',
    packages=[
        'facehugger',
    ],
    package_data={
        # If any package contains *.txt files, include them:
        '': ['*.py', '*.xml'],
    },
    scripts=["facehugger/facehugger.py"],
    package_dir={'facehugger': 'facehugger'},
    include_package_data=True,
    install_requires=[
        'SimpleCV',
    ],
    license="BSD",
    zip_safe=False,
    keywords=['facehugger', 'simplecv', 'vision', 'face', 'crawl'],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Topic :: Scientific/Engineering :: Image Recognition',
        'Topic :: Utilities',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
    ],
    test_suite='tests',
    # entry_points={
    #     'console_scripts': [
    #         'facehugger = facehugger.facehugger:main',
    #     ]
    # }
)
